Struct ark_r1cs_std::bits::uint128::UInt128 [−][src]
pub struct UInt128<F: Field> { /* fields omitted */ }
This struct represent an unsigned
128
bit integer as a sequence of
128
Booleans.
This is the R1CS equivalent of the native
u128
unsigned integer type.
Implementations
Turns self into the underlying little-endian bits.
Outputs self ^ other.
If at least one of self and other are constants, then this method
does not create any constraints or variables.
Perform modular addition of operands.
The user must ensure that overflow does not occur.