Struct ark_r1cs_std::bits::uint16::UInt16[][src]

pub struct UInt16<F: Field> { /* fields omitted */ }

This struct represent an unsigned 16 bit integer as a sequence of 16 Booleans. This is the R1CS equivalent of the native u16 unsigned integer type.

Implementations

impl<F: Field> UInt16<F>[src]

pub fn constant(value: u16) -> Self[src]

Construct a constant U16 from the native u16 type.

pub fn to_bits_le(&self) -> Vec<Boolean<F>>[src]

Turns self into the underlying little-endian bits.

pub fn from_bits_le(bits: &[Boolean<F>]) -> Self[src]

Construct Self from a slice of Booleans.

Panics

This method panics if bits.len() != 16 .

pub fn rotr(&self, by: usize) -> Self[src]

Rotates self to the right by by steps, wrapping around.

pub fn xor(&self, other: &Self) -> Result<Self, SynthesisError>[src]

Outputs self ^ other.

If at least one of self and other are constants, then this method does not create any constraints or variables.

pub fn addmany(operands: &[Self]) -> Result<Self, SynthesisError> where
    F: PrimeField
[src]

Perform modular addition of operands.

The user must ensure that overflow does not occur.