Crate ark_r1cs_std

Crate ark_r1cs_std 

This crate implements common “gadgets” that make programming rank-1 constraint systems easier.

Modules

alloc
Utilities for allocating new variables in a constraint system.
boolean
This module contains Boolean, an R1CS equivalent of the bool type.
cmp
Utilities for comparing variables.
convert
Utilities for converting variables to other kinds of variables.
eq
Utilities for checking equality of variables.
fields
Finite field arithmetic.
groups
Implementations of elliptic curve group arithmetic for popular curve models.
macros
Some utility macros for making downstream impls easier.
pairing
Gadgets for computing pairings in bilinear groups.
poly
Definitions of polynomial variables over finite fields.
prelude
select
Contains traits for conditionally selecting a variable from a list of variables.
uint
This module contains a macro for generating UIntN types, which are R1CS equivalents of N-bit unsigned integers.
uint8
This module contains UInt8, a R1CS equivalent of the u8 type.
uint16
This module contains UInt16, a R1CS equivalent of the u16 type.
uint32
This module contains UInt32, a R1CS equivalent of the u32 type.
uint64
This module contains UInt64, a R1CS equivalent of the u64 type.
uint128
This module contains UInt128, a R1CS equivalent of the u128 type.

Macros

impl_bounded_ops
Implements arithmetic traits (eg: Add, Sub, Mul) for the given type using the impl in $impl.
impl_bounded_ops_diff
Implements arithmetic traits (eg: Add, Sub, Mul) for the given type using the impl in $impl.
impl_ops
Implements arithmetic traits (eg: Add, Sub, Mul) for the given type using the impl in $impl.

Traits

Assignment
A utility trait to convert Self to Result<T, SynthesisErrorA.>