Module ark_r1cs_std::alloc [−][src]
This module describes a trait for allocating new variables in a constraint system.
Enums
| AllocationMode | Describes the mode that a variable should be allocated in within
a |
Traits
| AllocVar | Specifies how variables of type |