Enum ark_r1cs_std::alloc::AllocationMode [−][src]
Describes the mode that a variable should be allocated in within
a ConstraintSystem.
Variants
Indicate to the ConstraintSystem that the high-level variable should
be allocated as a constant. That is, no Variables should be
generated.
Indicate to the ConstraintSystem that the high-level variable should
be allocated as a public input to the ConstraintSystem.
Indicate to the ConstraintSystem that the high-level variable should
be allocated as a private witness to the ConstraintSystem.
Implementations
impl AllocationMode[src]
pub fn max(&self, other: Self) -> Self[src]
Outputs the maximum according to the relation Constant < Input < Witness.