Module ark_r1cs_std::bits::boolean [−][src]
This module contains Boolean, a R1CS equivalent of the bool type.
Structs
| AllocatedBit | Represents a variable in the constraint system which is guaranteed to be either zero or one. |
Enums
| Boolean | Represents a boolean value in the constraint system which is guaranteed to be either zero or one. |