Struct ark_r1cs_std::bits::boolean::AllocatedBit [−][src]
Represents a variable in the constraint system which is guaranteed to be either zero or one.
In general, one should prefer using Boolean instead of AllocatedBit,
as Boolean offers better support for constant values, and implements
more traits.
Implementations
impl<F: Field> AllocatedBit<F>[src]
pub fn value(&self) -> Result<bool, SynthesisError>[src]
Get the assigned value for self.
pub fn variable(&self) -> Variable[src]
Get the R1CS variable for self.
pub fn xor(&self, b: &Self) -> Result<Self, SynthesisError>[src]
Performs an XOR operation over the two operands, returning
an AllocatedBit.
pub fn and(&self, b: &Self) -> Result<Self, SynthesisError>[src]
Performs an AND operation over the two operands, returning
an AllocatedBit.
pub fn or(&self, b: &Self) -> Result<Self, SynthesisError>[src]
Performs an OR operation over the two operands, returning
an AllocatedBit.
pub fn and_not(&self, b: &Self) -> Result<Self, SynthesisError>[src]
Calculates a AND (NOT b).
pub fn nor(&self, b: &Self) -> Result<Self, SynthesisError>[src]
Calculates (NOT a) AND (NOT b).