Struct ark_r1cs_std::bits::uint32::UInt32 [−][src]
This struct represent an unsigned
32
bit integer as a sequence of
32
Booleans.
This is the R1CS equivalent of the native
u32
unsigned integer type.
Implementations
impl<F: Field> UInt32<F>[src]
pub fn constant(value: u32) -> Self[src]
Construct a constant
U32
from the native
u32
type.
pub fn to_bits_le(&self) -> Vec<Boolean<F>>[src]
Turns self into the underlying little-endian bits.
pub fn from_bits_le(bits: &[Boolean<F>]) -> Self[src]
pub fn rotr(&self, by: usize) -> Self[src]
Rotates self to the right by by steps, wrapping around.
pub fn xor(&self, other: &Self) -> Result<Self, SynthesisError>[src]
Outputs self ^ other.
If at least one of self and other are constants, then this method
does not create any constraints or variables.
pub fn addmany(operands: &[Self]) -> Result<Self, SynthesisError> where
F: PrimeField, [src]
F: PrimeField,
Perform modular addition of operands.
The user must ensure that overflow does not occur.