Module ark_r1cs_std::fields [−][src]
This module implements gadgets related to field arithmetic.
Modules
| cubic_extension | This module contains a generic implementation of cubic extension field
variables. That is, it implements the R1CS equivalent of
|
| fp | This module contains a generic implementation of prime field variables.
That is, it implements the R1CS equivalent of |
| fp2 | This module contains a generic implementation of the degree-2 tower
extension field. That is, it implements the R1CS equivalent of
|
| fp3 | This module contains a generic implementation of the degree-3 tower
extension field. That is, it implements the R1CS equivalent of
|
| fp4 | This module contains a generic implementation of the degree-4 tower
extension field. That is, it implements the R1CS equivalent of
|
| fp6_2over3 | This module contains a generic implementation of the degree-6 tower
extension field. That is, it implements the R1CS equivalent of
|
| fp6_3over2 | This module contains a generic implementation of the degree-6 tower
extension field. That is, it implements the R1CS equivalent of
|
| fp12 | This module contains a generic implementation of the degree-12 tower
extension field. That is, it implements the R1CS equivalent of
|
| quadratic_extension | This module contains a generic implementation of quadratic extension field
variables. That is, it implements the R1CS equivalent of
|
Traits
| FieldOpsBounds | This trait is a hack used to work around the lack of implied bounds. |
| FieldVar | A variable representing a field. Corresponds to the native type |