Enum ark_r1cs_std::fields::fp::FpVar [−][src]
Represent variables corresponding to a field element in F.
Variants
Represents a constant in the constraint system, which means that it does not have a corresponding variable.
Var(AllocatedFp<F>)Represents an allocated variable constant in the constraint system.
Implementations
impl<F: PrimeField> FpVar<F>[src]
pub fn enforce_cmp(
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<(), SynthesisError>[src]
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<(), SynthesisError>
This function enforces the ordering between self and other. The
constraint system will not be satisfied otherwise. If self should
also be checked for equality, e.g. self <= other instead of self < other, set should_also_check_quality to true. This variant
verifies self and other are <= (p-1)/2.
pub fn enforce_cmp_unchecked(
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<(), SynthesisError>[src]
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<(), SynthesisError>
This function enforces the ordering between self and other. The
constraint system will not be satisfied otherwise. If self should
also be checked for equality, e.g. self <= other instead of self < other, set should_also_check_quality to true. This variant
assumes self and other are <= (p-1)/2 and does not generate
constraints to verify that.
pub fn is_cmp(
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<Boolean<F>, SynthesisError>[src]
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<Boolean<F>, SynthesisError>
This function checks the ordering between self and other. It outputs
self Boolean that contains the result - 1 if true, 0
otherwise. The constraint system will be satisfied in any case. If
self should also be checked for equality, e.g. self <= other
instead of self < other, set should_also_check_quality to
true. This variant verifies self and other are <= (p-1)/2.
pub fn is_cmp_unchecked(
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<Boolean<F>, SynthesisError>[src]
&self,
other: &FpVar<F>,
ordering: Ordering,
should_also_check_equality: bool
) -> Result<Boolean<F>, SynthesisError>
This function checks the ordering between self and other. It outputs
a Boolean that contains the result - 1 if true, 0 otherwise.
The constraint system will be satisfied in any case. If self
should also be checked for equality, e.g. self <= other instead of
self < other, set should_also_check_quality to true. This
variant assumes self and other are <= (p-1)/2 and does not
generate constraints to verify that.
pub fn enforce_smaller_or_equal_than_mod_minus_one_div_two(
&self
) -> Result<(), SynthesisError>[src]
&self
) -> Result<(), SynthesisError>
Helper function to enforce that self <= (p-1)/2.