pub struct AllocatedFp<F: PrimeField> {
pub variable: Variable,
pub cs: ConstraintSystemRef<F>,
/* private fields */
}Expand description
Represents a variable in the constraint system whose value can be an arbitrary field element.
Fields
variable: VariableThe allocated variable corresponding to self in self.cs.
cs: ConstraintSystemRef<F>The constraint system that self was allocated in.
Implementations
Sourceimpl<F: PrimeField> AllocatedFp<F>
impl<F: PrimeField> AllocatedFp<F>
Sourcepub fn new(
value: Option<F>,
variable: Variable,
cs: ConstraintSystemRef<F>,
) -> Self
pub fn new( value: Option<F>, variable: Variable, cs: ConstraintSystemRef<F>, ) -> Self
Constructs a new AllocatedFp from a (optional) value, a low-level
Variable, and a ConstraintSystemRef.
Sourceimpl<F: PrimeField> AllocatedFp<F>
impl<F: PrimeField> AllocatedFp<F>
Sourcepub fn from(other: Boolean<F>) -> Self
pub fn from(other: Boolean<F>) -> Self
Constructs Self from a Boolean: if other is false, this outputs
zero, else it outputs one.
Sourcepub fn value(&self) -> Result<F, SynthesisError>
pub fn value(&self) -> Result<F, SynthesisError>
Returns the value assigned to self in the underlying constraint system
(if a value was assigned).
Sourcepub fn add(&self, other: &Self) -> Self
pub fn add(&self, other: &Self) -> Self
Outputs self + other.
This does not create any constraints.
Sourcepub fn add_many<B: Borrow<Self>>(iter: &[B]) -> Option<Self>
pub fn add_many<B: Borrow<Self>>(iter: &[B]) -> Option<Self>
Add many allocated Fp elements together.
This does not create any constraints and only creates one linear combination.
Returns None if you pass an empty iterator.
Sourcepub fn linear_combination<B1, B2, I1>(this: I1, other: &[B2]) -> Option<Self>
pub fn linear_combination<B1, B2, I1>(this: I1, other: &[B2]) -> Option<Self>
Computes the inner product of two iterators of AllocatedFp elements.
This does not create any constraints and only creates one linear combination.
Panics
Panics if the iterators are of different lengths.
Sourcepub fn inner_product<B1, B2, I1, I2>(this: I1, other: I2) -> Option<Self>
pub fn inner_product<B1, B2, I1, I2>(this: I1, other: I2) -> Option<Self>
Computes the inner product of two iterators of AllocatedFp elements.
This does not create any constraints and only creates one linear combination.
Panics
Panics if the iterators are of different lengths.
Sourcepub fn sub(&self, other: &Self) -> Self
pub fn sub(&self, other: &Self) -> Self
Outputs self - other.
This does not create any constraints.
Sourcepub fn add_constant(&self, other: F) -> Self
pub fn add_constant(&self, other: F) -> Self
Output self + other
This does not create any constraints.
Sourcepub fn sub_constant(&self, other: F) -> Self
pub fn sub_constant(&self, other: F) -> Self
Output self - other
This does not create any constraints.
Sourcepub fn mul_constant(&self, other: F) -> Self
pub fn mul_constant(&self, other: F) -> Self
Output self * other
This does not create any constraints.
Sourcepub fn double(&self) -> Result<Self, SynthesisError>
pub fn double(&self) -> Result<Self, SynthesisError>
Output self + self
This does not create any constraints.
Sourcepub fn negate_in_place(&mut self) -> &mut Self
pub fn negate_in_place(&mut self) -> &mut Self
Sets self = -self
This does not create any constraints.
Sourcepub fn square(&self) -> Result<Self, SynthesisError>
pub fn square(&self) -> Result<Self, SynthesisError>
Outputs self * self
This requires one constraint.
Sourcepub fn inverse(&self) -> Result<Self, SynthesisError>
pub fn inverse(&self) -> Result<Self, SynthesisError>
Outputs result such that result * self = 1.
This requires one constraint.
Sourcepub fn frobenius_map(&self, _: usize) -> Result<Self, SynthesisError>
pub fn frobenius_map(&self, _: usize) -> Result<Self, SynthesisError>
This is a no-op for prime fields.
Sourcepub fn mul_equals(
&self,
other: &Self,
result: &Self,
) -> Result<(), SynthesisError>
pub fn mul_equals( &self, other: &Self, result: &Self, ) -> Result<(), SynthesisError>
Enforces that self * other = result.
This requires one constraint.
Sourcepub fn square_equals(&self, result: &Self) -> Result<(), SynthesisError>
pub fn square_equals(&self, result: &Self) -> Result<(), SynthesisError>
Enforces that self * self = result.
This requires one constraint.
Sourcepub fn is_eq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>
pub fn is_eq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>
Outputs the bit self == other.
This requires two constraints.
Sourcepub fn is_neq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>
pub fn is_neq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>
Outputs the bit self != other.
This requires two constraints.
Sourcepub fn conditional_enforce_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>,
) -> Result<(), SynthesisError>
pub fn conditional_enforce_equal( &self, other: &Self, should_enforce: &Boolean<F>, ) -> Result<(), SynthesisError>
Enforces that self == other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.
Sourcepub fn conditional_enforce_not_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>,
) -> Result<(), SynthesisError>
pub fn conditional_enforce_not_equal( &self, other: &Self, should_enforce: &Boolean<F>, ) -> Result<(), SynthesisError>
Enforces that self != other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.