Struct ark_r1cs_std::fields::fp::AllocatedFp [−][src]
pub struct AllocatedFp<F: PrimeField> { pub variable: Variable, pub cs: ConstraintSystemRef<F>, // some fields omitted }
Represents a variable in the constraint system whose value can be an arbitrary field element.
Fields
variable: VariableThe allocated variable corresponding to self in self.cs.
cs: ConstraintSystemRef<F>The constraint system that self was allocated in.
Implementations
Constructs a new AllocatedFp from a (optional) value, a low-level
Variable, and a ConstraintSystemRef.
Constructs Self from a Boolean: if other is false, this outputs
zero, else it outputs one.
Returns the value assigned to self in the underlying constraint system
(if a value was assigned).
Outputs self + other.
This does not create any constraints.
Add many allocated Fp elements together.
This does not create any constraints and only creates one linear combination.
Outputs self - other.
This does not create any constraints.
Output self + other
This does not create any constraints.
Output self - other
This does not create any constraints.
Output self * other
This does not create any constraints.
Output self + self
This does not create any constraints.
Sets self = -self
This does not create any constraints.
Outputs self * self
This requires one constraint.
Outputs result such that result * self = 1.
This requires one constraint.
This is a no-op for prime fields.
Enforces that self * other = result.
This requires one constraint.
Enforces that self * self = result.
This requires one constraint.
Outputs the bit self == other.
This requires three constraints.
Outputs the bit self != other.
This requires three constraints.
pub fn conditional_enforce_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>
pub fn conditional_enforce_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>Enforces that self == other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.
pub fn conditional_enforce_not_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>
pub fn conditional_enforce_not_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>Enforces that self != other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.