Struct ark_r1cs_std::fields::fp::AllocatedFp [−][src]
Represents a variable in the constraint system whose value can be an arbitrary field element.
Fields
variable: VariableThe allocated variable corresponding to self in self.cs.
cs: ConstraintSystemRef<F>The constraint system that self was allocated in.
Implementations
impl<F: PrimeField> AllocatedFp<F>[src]
pub fn new(
value: Option<F>,
variable: Variable,
cs: ConstraintSystemRef<F>
) -> Self[src]
value: Option<F>,
variable: Variable,
cs: ConstraintSystemRef<F>
) -> Self
Constructs a new AllocatedFp from a (optional) value, a low-level
Variable, and a ConstraintSystemRef.
impl<F: PrimeField> AllocatedFp<F>[src]
pub fn from(other: Boolean<F>) -> Self[src]
Constructs Self from a Boolean: if other is false, this outputs
zero, else it outputs one.
pub fn value(&self) -> Result<F, SynthesisError>[src]
Returns the value assigned to self in the underlying constraint system
(if a value was assigned).
pub fn add(&self, other: &Self) -> Self[src]
Outputs self + other.
This does not create any constraints.
pub fn sub(&self, other: &Self) -> Self[src]
Outputs self - other.
This does not create any constraints.
pub fn mul(&self, other: &Self) -> Self[src]
Outputs self * other.
This requires one constraint.
pub fn add_constant(&self, other: F) -> Self[src]
Output self + other
This does not create any constraints.
pub fn sub_constant(&self, other: F) -> Self[src]
Output self - other
This does not create any constraints.
pub fn mul_constant(&self, other: F) -> Self[src]
Output self * other
This does not create any constraints.
pub fn double(&self) -> Result<Self, SynthesisError>[src]
Output self + self
This does not create any constraints.
pub fn negate(&self) -> Self[src]
Output -self
This does not create any constraints.
pub fn negate_in_place(&mut self) -> &mut Self[src]
Sets self = -self
This does not create any constraints.
pub fn square(&self) -> Result<Self, SynthesisError>[src]
Outputs self * self
This requires one constraint.
pub fn inverse(&self) -> Result<Self, SynthesisError>[src]
Outputs result such that result * self = 1.
This requires one constraint.
pub fn frobenius_map(&self, _: usize) -> Result<Self, SynthesisError>[src]
This is a no-op for prime fields.
pub fn mul_equals(
&self,
other: &Self,
result: &Self
) -> Result<(), SynthesisError>[src]
&self,
other: &Self,
result: &Self
) -> Result<(), SynthesisError>
Enforces that self * other = result.
This requires one constraint.
pub fn square_equals(&self, result: &Self) -> Result<(), SynthesisError>[src]
Enforces that self * self = result.
This requires one constraint.
pub fn is_eq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>[src]
Outputs the bit self == other.
This requires three constraints.
pub fn is_neq(&self, other: &Self) -> Result<Boolean<F>, SynthesisError>[src]
Outputs the bit self != other.
This requires three constraints.
pub fn conditional_enforce_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>[src]
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>
Enforces that self == other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.
pub fn conditional_enforce_not_equal(
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>[src]
&self,
other: &Self,
should_enforce: &Boolean<F>
) -> Result<(), SynthesisError>
Enforces that self != other if should_enforce.is_eq(&Boolean::TRUE).
This requires one constraint.